Crate nrpm_tarball

Crate nrpm_tarball 

Functions

create
Create a tarball from path, which must exist and be a directory. Returned value with be a temporary File handle that is removed on Drop. Make sure to copy the file if persistence is needed!
extract_metadata
hash_content
Compute a hash of a set of paths and bytes. Hashes should be consistent regardless of path ordering.
hash_dir
Do a content hash of a directory. This may differ from a tarball content hash based on gitignores in parent directories on different systems.
hash_tarball
Take a tar archive and calculate a content based hash. Each file is separately hashed by hashing each path component followed by contents. A final hash is created by combining all file hashes in lexicographic order of file paths.