Create a tarball from path, which must exist and be a directory. Returned value with be
a temporary File handle that is removed on Drop. Make sure to copy the file if persistence is needed!
Take a tar archive and calculate a content based hash. Each file is separately hashed
by hashing each path component followed by contents. A final hash is created by combining
all file hashes in lexicographic order of file paths.